summaryrefslogtreecommitdiffstats
path: root/src/H5FO.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5FO.c')
-rw-r--r--src/H5FO.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/H5FO.c b/src/H5FO.c
index 7f34556..849a4db 100644
--- a/src/H5FO.c
+++ b/src/H5FO.c
@@ -40,9 +40,9 @@ static int interface_initialize_g = 0;
/* Information about object objects in a file */
typedef struct H5FO_open_obj_t {
- haddr_t addr; /* Address of object header for object */
+ haddr_t addr; /* Address of object header for object */
/* THIS MUST BE FIRST FOR TBBT ROUTINES */
- hid_t id; /* Current ID for object */
+ void *obj; /* Pointer to the object */
hbool_t deleted; /* Flag to indicate that the object was deleted from the file */
} H5FO_open_obj_t;
@@ -94,7 +94,7 @@ done:
PURPOSE
Checks if an object at an address is already open in the file.
USAGE
- hid_t H5FO_opened(f,addr)
+ void *H5FO_opened(f,addr)
const H5F_t *f; IN: File to check opened object info set
haddr_t addr; IN: Address of object to check
@@ -108,14 +108,14 @@ done:
EXAMPLES
REVISION LOG
--------------------------------------------------------------------------*/
-hid_t
+void *
H5FO_opened(const H5F_t *f, haddr_t addr)
{
H5TB_NODE *obj_node; /* TBBT node holding open object */
H5FO_open_obj_t *open_obj; /* Information about open object */
- hid_t ret_value; /* Return value */
+ void *ret_value; /* Return value */
- FUNC_ENTER_NOAPI(H5FO_opened,FAIL)
+ FUNC_ENTER_NOAPI(H5FO_opened,NULL)
/* Sanity check */
assert(f);
@@ -127,11 +127,11 @@ H5FO_opened(const H5F_t *f, haddr_t addr)
if((obj_node=H5TB_dfind(f->shared->open_objs,&addr,NULL))!=NULL) {
open_obj=H5TB_NODE_DATA(obj_node);
assert(open_obj);
- ret_value=open_obj->id;
+ ret_value=open_obj->obj;
assert(ret_value>0);
} /* end if */
else
- ret_value=FAIL;
+ ret_value=NULL;
done:
FUNC_LEAVE_NOAPI(ret_value)
@@ -144,10 +144,10 @@ done:
PURPOSE
Insert a newly opened object/ID pair into the opened object info set
USAGE
- herr_t H5FO_insert(f,addr,id)
+ herr_t H5FO_insert(f,addr,obj)
H5F_t *f; IN/OUT: File's opened object info set
haddr_t addr; IN: Address of object to insert
- hid_t id; IN: ID of object to insert
+ void *obj; IN: Pointer to object to insert
int type; IN: Type of object being inserted
RETURNS
@@ -160,7 +160,7 @@ done:
REVISION LOG
--------------------------------------------------------------------------*/
herr_t
-H5FO_insert(const H5F_t *f, haddr_t addr, hid_t id)
+H5FO_insert(const H5F_t *f, haddr_t addr, void * obj)
{
H5FO_open_obj_t *open_obj; /* Information about open object */
herr_t ret_value=SUCCEED; /* Return value */
@@ -172,7 +172,7 @@ H5FO_insert(const H5F_t *f, haddr_t addr, hid_t id)
assert(f->shared);
assert(f->shared->open_objs);
assert(H5F_addr_defined(addr));
- assert(id>0);
+ assert(obj);
/* Allocate new opened object information structure */
if((open_obj=H5FL_MALLOC(H5FO_open_obj_t))==NULL)
@@ -180,7 +180,7 @@ H5FO_insert(const H5F_t *f, haddr_t addr, hid_t id)
/* Assign information */
open_obj->addr=addr;
- open_obj->id=id;
+ open_obj->obj=obj;
open_obj->deleted=0;
/* Insert into TBBT */